#!/usr/local/bin/python
#!/usr/bin/python
#!python

import argparse
import sys
import os

parser = argparse.ArgumentParser(description='GRASP: Guided Reference-based Assembly of Short Peptides')
# required options: the query and the target
parser.add_argument('--query', dest='query', required=True, type=str)
parser.add_argument('--target', dest='target', required=True, type=str)
# optional options
parser.add_argument('--GRASP_path', dest='GRASP_path', default="", required=False, type=str, help="The GRASP home directory")
parser.add_argument('--work_space', dest='work_space', default='WorkSpace', required=False, type=str, help="The directory to hold indexing files")
parser.add_argument('--result_space', dest='result_space', default="Results", required=False, type=str, help="The directory to hold results")
parser.add_argument('--num_threads', dest='num_threads', default=1, required=False, type=int, help="Number of threads")
parser.add_argument('--seed_len', dest='seed_len', default=6, required=False, type=int, help="Length of the seed")
parser.add_argument('--alphabet', dest='alphabet', default='GBMR10', required=False, type=str, help="Reduced alphabet for seeding")
parser.add_argument('--scoring_matrix', dest='scoring_matrix', default='BLOSUM62', required=False, type=str, help="Amino-acid substitution matrix")
parser.add_argument('--gap_open', dest='gap_open', default=-11, required=False, type=int, help="Gap open penalty")
parser.add_argument('--gap_extension', dest='gap_extension', default=-1, required=False, type=int, help="Gap extension penalty")
parser.add_argument('--band_size', dest='band_size', default=40, required=False, type=int, help="Band size of sequence alignment")
parser.add_argument('--Evalue', dest='Evalue', default=10, required=False, type=int, help="E-value cutoff")
parser.add_argument('--back_check', dest='back_check', default=10, required=False, type=int, help="Minimum overlap for extension")
parser.add_argument('--write_certificate', dest='write_certificate', default=False, required=False, type=bool, help="Write alignments between reference and contigs")
# construct dictionary for the alphabet and scoring function
alf_dict = {'ALL20':0, 'DSSP5':1, 'DSSP10':2, 'GBMR4':3, 'GBMR10':4, 'HSDM5':5,
    'SDM6':6, 'MURPHY5':7, 'MURPHY10':8, 'TD5':9, 'TD10':10}
sma_dict = {'BLOSUM62':0, 'BLOSUM80':1, 'BLOSUM90':2, 'BLOSUM50':3, 'BLOSUM45':4,
    'PAM250':5, 'PAM70':6, 'PAM30':7}
args = parser.parse_args()
# check if the input alphabet and scoring matrix is supported
if not alf_dict.has_key(args.alphabet):
  print "The input alphabet is not supported. Supported alphabet:"
  for key in alf_dict:
    print "%s" % (key)
  sys.exit()
if not sma_dict.has_key(args.scoring_matrix):
  print "The input scoring matrix is not supported. Supported scoring matrix:"
  for key in sma_dict:
    print "%s" % (key)
  sys.exit()
out_alignment = 0
if args.write_certificate:
  out_alignment = 1
# try to find GRASP executables
GRASP_path = os.path.abspath(args.GRASP_path)
build_exe = GRASP_path + '/' + 'bin/Build'
search_exe = GRASP_path + '/' + 'bin/Search'
if not os.path.isfile(build_exe) or not os.path.isfile(search_exe):
  print "Directory " + GRASP_path + '/' + 'bin/Build' + " has been searched for GRASP executable."
  print "GRASP executable is not found. Please specify GRASP directory using \"--GRASP_path\" option"
# run the GRASP program
q_file = os.path.abspath(args.query)
t_file = os.path.abspath(args.target)
work_path = os.path.abspath(args.work_space)
result_path = os.path.abspath(args.result_space)
build_cmd = build_exe + " " + t_file + " --work_space=" + work_path \
    + " --seed_len=" + str(args.seed_len) + " --alphabet=" + str(alf_dict[args.alphabet])
print "Running \"" + build_cmd + "\" ..."
os.system(build_cmd)
search_cmd = search_exe + " " + q_file + " " + t_file + " --work_space=" + work_path \
    + " --result_space=" + result_path + " --scoring_matrix=" + str(sma_dict[args.scoring_matrix]) \
    + " --gap_open=" + str(args.gap_open) + " --gap_extension=" + str(args.gap_extension) \
    + " --band_size=" + str(args.band_size) + " --back_check=" + str(args.back_check) \
    + " --num_threads=" + str(args.num_threads) + " --write_certificate=" + str(out_alignment)
print "Running \"" + search_cmd + "\" ..."
os.system(search_cmd)
print "Done. Please check results in \"%s\"." % result_path






















